"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadStories = void 0;

var _chokidar = _interopRequireDefault(require("chokidar"));

var _browser = require("./browser");

var _logger = require("../../logger");

var _parser = _interopRequireDefault(require("../../testsFiles/parser"));

var _utils = require("../../../server/utils");

var _shared = require("../../../shared");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const loadStories = async (_config, _options, storiesListener) => {
  let creeveyParamsByStoryId = {};

  const mergeParamsFromTestsToStory = (story, creeveyParams) => {
    if (story.parameters) {
      story.parameters.creevey = (0, _shared.combineParameters)(story.parameters.creevey || {}, creeveyParams);
    }
  };

  const stories = await (0, _browser.loadStories)(_config, {}, updatedStoriesByFiles => {
    Array.from(updatedStoriesByFiles.entries()).forEach(([, storiesArray]) => {
      storiesArray.forEach(story => {
        const creeveyParams = creeveyParamsByStoryId[story.id];

        if (creeveyParams) {
          mergeParamsFromTestsToStory(story, creeveyParams);
        }
      });
    });
    storiesListener(updatedStoriesByFiles);
  }); // TODO fix test files hot reloading

  creeveyParamsByStoryId = await parseParams(_config
  /*, (data) => console.log(data) */
  );
  Object.entries(stories).forEach(([storyId, story]) => {
    mergeParamsFromTestsToStory(story, creeveyParamsByStoryId[storyId]);
  });
  return stories;
};

exports.loadStories = loadStories;

async function parseParams(config, listener) {
  if (!config.testsDir) {
    return Promise.resolve({});
  }

  const testFiles = (0, _utils.readDirRecursive)(config.testsDir).filter(file => {
    var _config$testsRegex;

    return (_config$testsRegex = config.testsRegex) === null || _config$testsRegex === void 0 ? void 0 : _config$testsRegex.test(file);
  });
  await (await Promise.resolve().then(() => _interopRequireWildcard(require('../../testsFiles/register')))).default(config);

  if (listener) {
    _chokidar.default.watch(testFiles).on('change', filePath => {
      _logger.logger.debug(`changed: ${filePath}`); // doesn't work, always returns {} due modules caching
      // see https://github.com/nodejs/modules/issues/307


      void (0, _parser.default)(testFiles).then(data => listener(data));
    });
  }

  return (0, _parser.default)(testFiles);
}